//+------------------------------------------------------------------+
//|                                                  MarketZones.mq4 |
//|                                         Copyright  2011, Geafer |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Copyright  2011, Geafer"
#property link      ""

#property indicator_chart_window

//---- vstupn parametry
extern bool      London_Show = true;
extern color     London_Color = Blue;
extern string    London_Text = "London";

//---- zkladn nzvy objekt
string London_BaseName = "MZLondon";

// inicializace
int init()
{  
   // pokud se m zobrazit London, vytvome MZ
   if(London_Show)
   {
      createMZ(London_BaseName, London_Color, London_Text);
   }
   
   return(0);
}

// deinicializace
int deinit()
{
   // smazn MZ pro London
   deleteMZ(London_BaseName);
   
   return(0);
}

// bh indiktoru
int start()
{
   string currentDate = TimeToStr(TimeCurrent(), TIME_DATE);
     
   // pokud se m vykreslit London, pekreslme MZ   
   if(London_Show)
   {
      redrawMZ(London_BaseName, currentDate, "09:00", "17:59");
   }      

   return(0);
}

// vytvo vertikln linii
// name = nzev linie
// c = barva linie
void createVLine(string name, color c)
{
   // kontrola, zda objekt neexistuje
   if(ObjectFind(name) < 0)
   {
      // pokud se podailo objekt vytvoit, meme nastavit vlastnosti
      if(ObjectCreate(name, OBJ_VLINE, 0, 0, 0))
      {
         ObjectSet(name, OBJPROP_COLOR, c);
         ObjectSet(name, OBJPROP_STYLE, STYLE_DOT);
         ObjectSet(name, OBJPROP_BACK, true);
         ObjectSet(name, OBJPROP_TIMEFRAMES, OBJ_PERIOD_M1|OBJ_PERIOD_M5|OBJ_PERIOD_M15|OBJ_PERIOD_M30|OBJ_PERIOD_H1);
      }
   }
}

// pekresl vertikln linii
// name = nzev linie
// dt = datum umstn linie
void redrawVLine(string name, datetime dt)
{
   if(ObjectFind(name) > -1)
   {
      ObjectSet(name, OBJPROP_TIME1, dt);
   }
}

// vytvo textov objekt
// name = nzev textovho objektu
// text = zobrazovan text
// c = barva textu
void createText(string name, string text, color c)
{
   // kontrola, zda objekt neexistuje
   if(ObjectFind(name) < 0)
   {
      // pokud se podailo objekt vytvoit, meme nastavit vlastnosti
      if(ObjectCreate(name, OBJ_TEXT, 0, 0, 0))
      {
         ObjectSetText(name, text, 8, "Arial", c);
         ObjectSet(name, OBJPROP_ANGLE, 90);
         ObjectSet(name, OBJPROP_TIMEFRAMES, OBJ_PERIOD_M1|OBJ_PERIOD_M5|OBJ_PERIOD_M15|OBJ_PERIOD_M30|OBJ_PERIOD_H1);
      }
   }
}

// pekresl textov objekt
// name = nzev textovho objektu
// dt = datum umstn textovho objektu
void redrawText(string name, datetime dt)
{
   if(ObjectFind(name) > -1)
   {
      ObjectSet(name, OBJPROP_TIME1, dt);
      ObjectSet(name, OBJPROP_PRICE1, (WindowPriceMax() - WindowPriceMin()) / 2 + WindowPriceMin());
   }
}

// vytvo MarketZone (MZ) linie
// baseName = zkladn nzev MZ
// c = barva MZ
// text = popisek MZ
void createMZ(string baseName, color c, string text)
{
   // nzev linie zobrazujc oteven marketu
   string nameOpen = baseName + "Open";
   // nzev linie zobrazujc zaven marketu
   string nameClose = baseName + "Close";
   // nzev textu zobrazujc popis marketu
   string nameText = baseName + "Text";
   
   createVLine(nameOpen, c);
   createVLine(nameClose, c);
   createText(nameText, text, c);
}

// odstran MarketZone linie
// baseName = zkladn nzev MZ
void deleteMZ(string baseName)
{
   ObjectDelete(baseName + "Open");
   ObjectDelete(baseName + "Close");
   ObjectDelete(baseName + "Text");
}

// pekresl MarketZone linii
// baseName = zkladn nzev MZ
// currentDate = etzec aktulnho datumu (bez asu)
// timeOpen = etzec asu oteven marketu
// timeClose = etzec asu zaven marketu
void redrawMZ(string baseName, string currentDate, string timeOpen, string timeClose)
{
   // nzev linie zobrazujc oteven marketu
   string nameOpen = baseName + "Open";
   // nzev linie zobrazujc zaven marketu
   string nameClose = baseName + "Close";
   // nzev textu zobrazujc popis marketu
   string nameText = baseName + "Text";
   
   // vytvoen datumu pro otevrac a zavrac dobu
   datetime dtOpen = StrToTime(currentDate + " " + timeOpen);
   datetime dtClose = StrToTime(currentDate + " " + timeClose);
   
   redrawVLine(nameOpen, dtOpen);
   redrawVLine(nameClose, dtClose);
   redrawText(nameText, dtOpen);
   
   WindowRedraw();
}